# GHANIAN COUNTRIES INFORMATIONS

## Step 1: Install The Package Via Pip

#### Via Pip
```python
 pip3 install ghana
```


## Step 2: Initialize
```python
#IMPORT 
import ghana

```

### Getting data
```python
# Using the print() function to print the data out

print(ghana.country_data)

print(ghana.regions)

print(ghana.capitals)
```

### Getting clip art
```python
# Initialize clip art function

ghana.region_art()
ghana.capital_art()
ghana.ghana_art()
```